@@ -47,6 +47,7 @@ class RxConnectionAgent(ConnectionAgentBase):
     WARN: Due to the fact that it uses a dictionary as backing store many connections could eat up lots and lots of memory
     """
     _log = LogFactory.get_logger(__name__)
+    _verbosity = LogFactory.verbosity()
 
     def __init__(self, evaluation_fn: Callable[[Subject], Observable], outbound_queue: Queue):
         self._connections = {}
@@ -63,7 +64,8 @@ class RxConnectionAgent(ConnectionAgentBase):
             outbound = self._evaluation_fn(subject)
             outbound \
                 .subscribe(SendingObserver(identity, self._outbound_queue))
-            self._log.debug("[CONTROL] Added new connection (identity=%s)", identity)
+            if self._verbosity == 'EXTENDED':
+                self._log.debug("[CONTROL] Added new connection (identity=%s)", identity)
             connection = RxStreamConnection(identity, subject, outbound)
             self._connections[identity] = connection
             return connection
