@@ -8,12 +8,13 @@ from interstate_py.stream_connection import StreamConnection
 
 
 class RxStreamConnection(StreamConnection):
-
     _log = LogFactory.get_logger(__name__)
+    _verbosity = LogFactory.verbosity()
 
     """
     Concrete StreamConnection using RxPY 1.x under the hood.
     """
+
     def __init__(self,
                  identity: str,
                  inbound: Subject,
@@ -37,7 +38,8 @@ class RxStreamConnection(StreamConnection):
 
     def close_inbound(self):
         try:
-            self._log.debug("Closing inbound connection for %s", self._identity)
+            if self._verbosity == 'EXTENDED':
+                self._log.debug("Closing inbound connection for %s", self._identity)
             self._inbound_subject.check_disposed()  # throws
             self._inbound_subject.dispose()
             self._close_count = self._close_count + 1
@@ -46,5 +48,6 @@ class RxStreamConnection(StreamConnection):
 
     def close_outbound(self):
         if self._close_count < 2:
-            self._log.debug("Closing outbound connection for %s", self._identity)
+            if self._verbosity == 'EXTENDED':
+                self._log.debug("Closing outbound connection for %s", self._identity)
             self._close_count = self._close_count + 1
