@@ -1,4 +1,4 @@
-import asyncio
+import os
 from asyncio import Queue
 from concurrent.futures.thread import ThreadPoolExecutor
 from typing import Any
@@ -13,7 +13,6 @@ from interstate_py.interstate_message import InterstateWireMessageType, Intersta
 from interstate_py.log_factory import LogFactory
 from interstate_py.multiplex_message import MultiplexMessage
 from interstate_py.serialization.serialization import Serialization
-from interstate_py.stream_connection import StreamConnection
 
 
 class StreamDemultiplexer(AIOWorkerTask):
@@ -22,6 +21,7 @@ class StreamDemultiplexer(AIOWorkerTask):
     the corresponding connection provided by the connection agent.
     """
     _log = LogFactory.get_logger(__name__)
+    _verbosity = LogFactory.verbosity()
 
     def __init__(self, raw_inbound_queue: Queue,
                  outbound_queue: janus.Queue,
@@ -39,11 +39,11 @@ class StreamDemultiplexer(AIOWorkerTask):
         identity = message.identity.decode()
         connection = self._con_agent.get(identity)
 
-        def _dispatch(connection: StreamConnection, payload):
+        if message.type == InterstateWireMessageType.NEXT:
+            self._log.debug("[IN][NEXT] - {}".format(message))
+            deserialized_payload = await self._deserialize(message)
             try:
-                self._log.debug("Sending payload to subject")
-                connection.inbound_stream().on_next(payload)
-                self._log.debug("Payload sent to subject")
+                connection.inbound_stream().on_next(deserialized_payload)
             except DisposedException:
                 self._log.warn("Connection (%s) has already been disposed but not garbage collected", identity)
                 self._con_agent.dump(connection.identity())
@@ -54,24 +54,18 @@ class StreamDemultiplexer(AIOWorkerTask):
                                      ErrorAssembly.to_error(ErrorAssembly.GENERAL,
                                                             e)))
 
-        if message.type == InterstateWireMessageType.NEXT:
-            self._log.debug("[IN][NEXT] - {}".format(message))
-            deserialized_payload = await self._deserialize(message)
-            asyncio.get_event_loop().run_in_executor(self._pool,  # TODO: configurable
-                                                     _dispatch,
-                                                     connection,
-                                                     deserialized_payload)
-
         elif message.type == InterstateWireMessageType.ERROR:
             self._log.warn("[IN][ERROR] - {}".format(message))
             connection.inbound_stream().on_error(Exception("Error"))
             connection.close_inbound()
         elif message.type == InterstateWireMessageType.COMPLETE:
-            self._log.debug("[IN][COMPLETED] - {}".format(message))
+            if  self._verbosity == 'EXTENDED':
+                self._log.debug("[IN][COMPLETED] - {}".format(message))
             connection.inbound_stream().on_completed()
             connection.close_inbound()
         elif message.type == InterstateWireMessageType.PING:
-            self._log.debug("[IN][PING] - {}".format(message))
+            if  self._verbosity == 'EXTENDED':
+                self._log.debug("[IN][PING] - {}".format(message))
             await self._outbound_queue.async_q.put(
                 MultiplexMessage(identity, InterstateWireMessageType.PONG, "pong".encode()))
         else:
