@@ -19,6 +19,7 @@ class StreamMultiplexer(AIOWorkerTask):
     If a serialization object is passed, the payload will be serialized to bytes.
     """
     _log = LogFactory.get_logger(__name__)
+    _verbosity = LogFactory.verbosity
 
     def __init__(self,
                  outbound_queue: janus.Queue,
@@ -46,14 +47,16 @@ class StreamMultiplexer(AIOWorkerTask):
             await self._raw_outbound_queue.put(ErrorAssembly.to_on_error(multiplex_message))
             connection.close_outbound()
         elif multiplex_message.type == InterstateWireMessageType.COMPLETE:
-            self._log.debug("[OUT][COMPLETED] - {}".format(multiplex_message))
+            if self._verbosity == 'EXTENDED':
+                self._log.debug("[OUT][COMPLETED] - {}".format(multiplex_message))
             await self._raw_outbound_queue.put(
                 InterstateWireMessage(multiplex_message.identity.encode(), InterstateWireMessageType.header("complete"),
                                       bytes(0))
             )
             connection.close_outbound()
         elif multiplex_message.type == InterstateWireMessageType.PONG:
-            self._log.debug("[OUT][PONG] - {}".format(multiplex_message))
+            if self._verbosity == 'EXTENDED':
+                self._log.debug("[OUT][PONG] - {}".format(multiplex_message))
             await self._raw_outbound_queue.put(
                 InterstateWireMessage(multiplex_message.identity.encode(), InterstateWireMessageType.header("pong"),
                                       bytes(0))
